+++
title = "HCC Documentation"
description = "HCC Documentation Home"
weight = "1"
+++

HCC Documentation
============================


The Holland Computing Center supports a diverse collection of research
computing hardware.  Anyone in the University of Nebraska system is
welcome to apply for an account on HCC machines.

Access to these resources is by default shared with the rest of the user
community via various job schedulers. These policies may be found on the
pages for the various resources. Alternatively, a user may buy into an
existing resource, acquiring 'priority access'. Finally, several
machines are available via Condor for opportunistic use. This will allow
users almost immediate access, but the job is subject to preemption.

#### [New Users Sign Up](http://hcc.unl.edu/new-user-request)

#### [Quick Start Guides](/quickstarts)

Which Cluster to Use?
---------------------

**Crane**: Crane is the newest and most powerful HCC resource . If you
are new to using HCC resources, Crane is the recommended cluster to use
initially.  Limitations: Crane has only 2 CPU/16 cores and 64GB RAM per
node. CraneOPA has 2 CPU/36 cores with a maximum of 512GB RAM per node. 
If your job requires more than 36 cores per node or you need more than
512GB of memory, consider using Tusker instead.

**Tusker**: Similar to Crane, Tusker is another cluster shared by all
campus users. It has 4 CPU/ 64 cores and 256GB RAM per node. Two nodes
have 1024GB RAM for very large memory jobs. So for jobs requiring more
than 36 cores per node or large memory, Tusker would be a better option.

User Login
----------

For Windows users, please refer to this link [For Windows Users]({{< relref "for_windows_users" >}}).
For Mac or Linux users, please refer to this link [For Mac/Linux Users]({{< relref "for_maclinux_users">}}).

**Logging into Crane or Tusker**

{{< highlight bash >}}
ssh <username>@crane.unl.edu
or
ssh <username>@tusker.unl.edu
{{< /highlight >}}

Duo Security
------------

Duo two-factor authentication is **required** for access to HCC
resources. Registration and usage of Duo security can be found in this
section: [Setting up and using Duo]({{< relref "setting_up_and_using_duo">}})

**Important Notes**

-   The Crane and Tusker clusters are separate. But, they are
    similar enough that submission scripts on whichever one will work on
    another, and vice versa.    
     
-   The worker nodes cannot write to the `/home` directories. You must
    use your `/work` directory for processing in your job. You may
    access your work directory by using the command:
{{< highlight bash >}}
$ cd $WORK
{{< /highlight >}}

Resources
---------

- ##### Crane - HCC's newest machine, Crane has 7232 Intel Xeon cores in 452 nodes with 64GB RAM per node.

- ##### Tusker - consists of 106 AMD Interlagos-based nodes (6784 cores) interconnected with Mellanox QDR Infiniband.

- ##### Red - This cluster is the resource for UNL's US CMS Tier-2 site.

    - [CMS](http://www.uscms.org/)
    - [Open Science Grid](http://www.opensciencegrid.org)
    - [MyOSG](https://myosg.grid.iu.edu/)

- ##### Anvil - HCC's cloud computing cluster based on Openstack

- ##### Glidein - A gateway to running jobs on the OSG, a collection of computing resources across the US.

Resource Capabilities
---------------------

| Cluster | Overview | Processors | RAM | Connection | Storage
| ------- | ---------| ---------- | --- | ---------- | ------
| **Crane**   | 548 node Production-mode LINUX cluster | 452 Intel Xeon E5-2670 2.60GHz 2 CPU/16 cores per node<br> <br>116 Intel Xeon E5-2697 v4 2.3GHz, 2 CPU/36 cores per node<br><br>("CraneOPA") | 452 nodes @ \*64GB<br><br>79 nodes @ \*\*256GB<br><br>37 nodes @ \*\*\*512GB | QDR Infiniband<br><br>EDR Omni-Path Architecture | ~1.8 TB local scratch per node<br><br>~4 TB local scratch per node<br><br>~1452 TB shared Lustre storage
| **Tusker**  | 82 node Production-mode LINUX cluster | Opteron 6272 2.1GHz, 4 CPU/64 cores per node | \*\*256 GB RAM per node<br>\*\*\*2 Nodes with 512GB per node<br>\*\*\*\*2 Nodes with 1024GB per node | QDR Infiniband | ~500 TB shared Lustre storage<br>~500GB local scratch |
| **Red** | 344 node Production-mode LINUX cluster | Various Xeon and  Opteron processors 7,280 cores maximum, actual number of job slots depends on RAM usage | 1.5-4GB RAM per job slot | 1Gb, 10Gb, and 40Gb Ethernet | ~6.67PB of raw storage space |
| **Anvil** | 76 Compute nodes (Partially used for cloud, the rest used for general computing), 12 Storage nodes, 2 Network nodes Openstack cloud | 76 Intel Xeon E5-2650 v3 2.30GHz 2 CPU/20 cores per node | 76 nodes @ 256GB | 10Gb Ethernet | 528 TB Ceph shared storage (349TB available now) |

You may only request the following amount of RAM: <br>
\*62.5GB <br>
\*\*250GB <br>
\*\*\*500GB <br>
\*\*\*\*1000GB

