+++
title = "Using Attic"
description = "How to store data on Attic"
weight = 20
+++

For users who need long-term storage for large amount of data, HCC
provides an economical solution called Attic.  Attic is a reliable
<a href="https://en.wikipedia.org/wiki/Nearline_storage" class="external-link">near-line data archive</a> storage
system. The files in Attic can be accessed and shared from anywhere
using [Globus
Connect]({{< relref "globus_connect" >}}),
with a fast 10Gb/s link.  Also, the data in Attic is backed up between
our Lincoln and Omaha facilities to ensure high availability and
disaster tolerance. The data and user activities on Attic are subject to
our
<a href="http://hcc.unl.edu/hcc-policies" class="external-link">HCC Policies</a>.

---
### Accounts and Cost

To use Attic you will first need an
<a href="https://hcc.unl.edu/new-user-request" class="external-link">HCC account</a>, and
then you may request an
<a href="http://hcc.unl.edu/attic" class="external-link">Attic allocation</a>.
We charge a small fee per TB per year, but it is cheaper than most
commercial cloud storage solutions.  For the user application form and
cost, please see the
<a href="http://hcc.unl.edu/attic" class="external-link">HCC Attic page</a>.

---
### Transfer Files Using Globus Connect

The easiest and fastest way to access Attic is via Globus. You can
transfer files between your computer, our clusters ($HOME, $WORK, and $COMMON on
Crane and Tusker), and Attic. Here is a detailed tutorial on
how to set up and use [Globus Connect]({{< relref "globus_connect" >}}). For
Attic, use the Globus Endpoint **hcc\#attic**.  Your Attic files are
located at `~, `which is a shortcut
for `/attic/<groupname>/<username>`.  
**Note:** *If you are accessing Attic files from your supplementary
group, you should explicitly set the path to
/attic/&lt;supplementary\_groupname&gt;/. If you don't do that, by
default the endpoint will try to place you in your primary group's Attic
path, to which access will be denied if the primary group doesn't have an Attic allocation.*

---
### Transfer Files Using SCP/SFTP/RSYNC

The transfer server for Attic storage is `attic.unl.edu` (or `attic-xfer.unl.edu`).

{{% panel theme="info" header="SCP Example" %}}
{{< highlight bash >}}
scp /source/file <username>@attic.unl.edu:~/destination/file
{{< /highlight >}}
{{% /panel %}}

{{% panel theme="info" header="SFTP Example" %}}
{{< highlight bash >}}
sftp <username>@attic.unl.edu
Password:
Duo two-factor login for <username>
Connected to attic.unl.edu.
sftp> pwd
Remote working directory: /attic/<groupname>/<username>
sftp> put source/file destination/file
sftp> exit
{{< /highlight >}}
{{% /panel %}}

{{% panel theme="info" header="RSYNC Example" %}}
{{< highlight bash >}}
# local to remote rsync command
rsync -avz /local/source/path <username>@attic.unl.edu:remote/destination/path

# remote to local rsync command
rsync -avz <username>@attic.unl.edu:remote/source/path /local/destination/path
{{< /highlight >}}
{{% /panel %}}

You can also access your data on Attic using our [high-speed
transfer servers]({{< relref "high_speed_data_transfers" >}}) if you prefer.
Simply use scp or sftp to connect to one of the transfer servers, and
your directory is mounted at `/attic/<groupname>/<username>`.

---
### Check Attic Usage

The usage and quota information for your group and the users in the
group are stored in a file named "disk\_usage.txt" in your group's
directory (`/attic/<groupname>`). You can use either [Globus Connect]({{< relref "globus_connect" >}}) or
scp to download it.  Your usage and expiration is also shown in the web
interface (see below).

---
### Use the web interface

For convenience, a web interface is also provided.  Simply go to
<a href="https://attic.unl.edu" class="external-link">https://attic.unl.edu</a>
and login with your HCC credentials.  Using this interface, you can see
your quota usage and expiration, manage files, etc.  **Please note we do
not recommend uploading/downloading large files this way**.  Use one of
the other transfer methods above for large datasets.


