+++
title = "Submitting an MPI Job"
description =  "How to submit an MPI job on HCC resources."
+++

This script requests 16 cores on nodes with InfiniBand:

{{% panel theme="info" header="mpi.submit" %}}
{{< highlight batch >}}
#!/bin/sh
#SBATCH --ntasks=16
#SBATCH --mem-per-cpu=1024
#SBATCH --time=03:15:00
#SBATCH --error=/work/[groupname]/[username]/job.%J.err
#SBATCH --output=/work/[groupname]/[username]/job.%J.out

module load compiler/gcc/8.2 openmpi/2.1
mpirun /home/[groupname]/[username]/mpiprogram
{{< /highlight >}}
{{% /panel %}}

The above job will allocate 16 cores on the default partition.  The 16
cores could be on any of the nodes in the partition, even split between
multiple nodes.

### Advanced Submission

Some users may prefer to specify more details. This will allocate 32
tasks, 16 on each of two nodes:

{{% panel theme="info" header="mpi.submit" %}}
{{< highlight batch >}}
#!/bin/sh  
#SBATCH --nodes=2  
#SBATCH --ntasks-per-node=16  
#SBATCH --mem-per-cpu=1024  
#SBATCH --time=03:15:00  
#SBATCH --error=/work/[groupname]/[username]/job.%J.err  
#SBATCH --output=/work/[groupname]/[username]/job.%J.out

module load compiler/gcc/8.2 openmpi/2.1
mpirun /home/[groupname]/[username]/mpiprogram
{{< /highlight >}}
{{% /panel %}}
