+++
title = "For Windows Users"
description = "Quickstart for Windows Users"
weight = "20"
+++

##### Use of Duo two-factor authentication is **required** to access HCC resources. 
##### Please see [Setting up and Using Duo]({{< relref "setting_up_and_using_duo" >}}).
---


- [Access to HCC Supercomputers] (#access-to-hcc-supercomputers)
 - [For Windows 10 Users](#windows-10)
 - [For Windows 7 and 8.1 Users](#windows-7-and-8-1)
- [File Transferring with HCC Supercomputers] (#file-transferring)
 - [SCP - Command Line] (#scp)
 - [WinSCP - GUI] (#winscp)
- [Tutorial Video](#tutorial-video)
 
Access to HCC Supercomputers
-------------------------------

{{% notice info %}}
If you are on a Mac, please use the quickstart for [For Mac/Linux
Users]({{< relref "for_maclinux_users" >}}).
{{% /notice %}}


### Windows 10
--------------
For Windows 10 users, use the Command Prompt, accessed by entering `cmd` in the start menu, to access to the
HCC supercomputers. In the Command Prompt,
type `ssh <username>@tusker.unl.edu` and the corresponding password
to get access to the HCC cluster **Tusker**. Note that &lt;username&gt;
should be replaced by your HCC account username. If you do not have a
HCC account, please contact a HCC specialist
({{< icon name="envelope" >}}[hcc-support@unl.edu] (mailto:hcc-support@unl.edu))
or go to http://hcc.unl.edu/newusers.
To use the **Crane** cluster, replace tusker.unl.edu with crane.unl.edu.

{{< highlight bash >}}
C:\> ssh <username>@tusker.unl.edu
C:\> <password>
{{< /highlight >}}



### Windows 7 and 8.1
--------------
This quick start will help you configure your personal computer to work
with the HCC supercomputers. Here we use the two third party application
**PuTTY** and **WinSCP** for demonstration.

PuTTY: https://www.chiark.greenend.org.uk/~sgtatham/putty/latest.html
or [Direct Link](https://the.earth.li/~sgtatham/putty/latest/w32/putty.exe)


Here we use the HCC cluster **Tusker** for demonstration. To use the
**Crane** or cluster, replace `tusker.unl.edu` with `crane.unl.edu`.

1.  On the first screen, type `tusker.unl.edu` for Host Name, then click
    **Open**. 
    {{< figure src="/images/3178523.png" height="450" >}}
2.  On the second screen, click on **Yes**.  
    {{< figure src="/images/3178524.png" height="300" >}}
3.  On the third screen, enter your HCC account **username**. If you do
    not have a HCC account, please contact an HCC specialist
    ({{< icon name="envelope" >}}[hcc-support@unl.edu] (mailto:hcc-support@unl.edu))
    or go to http://hcc.unl.edu/newusers.

    {{% notice info %}}Replace `jingchao` with your username.{{% /notice %}}


    {{< figure src="/images/8127261.png" height="450" >}}      

4.  On the next screen, enter your HCC account **password**. 

    {{% notice info %}}**Note that PuTTY will not show the characters as you type for security reasons.**{{% /notice %}} 

    {{< figure src="/images/8127262.png" height="450" >}}

5.  After you input the correct
    password, you will be asked to choose a Duo authentication
    method.
      
6.  If you have a Yubikey set up by HCC, please hold the Yubikey for \~1
    second. Then you will be brought to your home directory similar as
    below.   
     
    {{< figure src="/images/8127266.png" height="450" >}} 
      
7.  If you set up Duo via a smart phone, please type "1" in your
    terminal and press "Enter". (Duo-Push is the most cost-effective way
    for Duo authentication, we recommend all user use this option if
    that is applicable.)  
      
8.  Check your smart phone for Duo login request. Press "Approve" if you
    can verify the request. If you find any Duo login request that is
    not initiated by yourself, deny it and report this incident
    immediately to {{< icon name="envelope" >}}[hcc-support@unl.edu] (mailto:hcc-support@unl.edu).

    {{< figure src="/images/8127263.png" height="450" >}}      
      
9.  After you approve the Duo login request, you will be brought to your
    home directory similar as below.  

    {{< figure src="/images/8127264.png" height="450" >}}
 

File Transferring with HCC Supercomputers
-----------------------------------------

{{% notice info%}}
For best results when transfering data to and from the clusters, refer to [Handling Data]({{< ref "/guides/handling_data" >}})
{{%/notice%}}

### SCP

For Windows users, file transferring between your personal computer
and the HCC supercomputers can be achieved through the command `scp`.
Here we use **Tusker** for example. **The following commands should be
executed from your computer. **

**Uploading from local to remote**

{{< highlight bash >}}
C:\> scp -r .\<folder name> <username>@tusker.unl.edu:/work/<group name>/<username>
{{< /highlight >}}

The above command line transfers a folder from the current directory
(`.\`) of the your computer to the `$WORK` directory of the HCC
supercomputer, Tusker. Note that you need to replace `<group name>`
and `<username>` with your HCC group name and username. 

**Downloading from remote to local**

{{< highlight bash >}}
C:\> scp -r <username>@tusker.unl.edu:/work/<group name>/<username>/<folder name> .\
{{< /highlight >}}

The above command line transfers a folder from the `$WORK` directory of
the HCC supercomputer, Tusker, to the current directory (`.\`) of the
your computer.


### WinSCP

WinSCP: http://winscp.net/eng/download.php

Usually it is convenient to upload and download files between your personal computer 
and the HCC supercomputers through a Graphic User Interface (GUI).
Download and install the third party application **WinSCP**
to connect the file systems between your personal computer and the HCC supercomputers. 
Below is a step-by-step installation guide. Here we use the HCC cluster **Tusker**
for demonstration. To use the **Crane** cluster, replace `tusker.unl.edu`
with `crane.unl.edu`.

1.  On the first screen, type `tusker.unl.edu` for Host name, enter your
    HCC account username and password for User name and Password. Then
    click on **Login**.

    {{< figure src="/images/3178530.png" height="450" >}}

2.  On the second screen, click on **Yes**.  

    {{< figure src="/images/3178531.png" >}}

3.  Choose option "1" and press "Enter". Or simply press your Yubikey if
    you have one.

    {{< figure src="/images/8127268.png" >}}      

4.  On the third screen, click on **Remote**. Under Remote, choose Go To
    and Open Directory/Bookmark. Alternatively, you can use the keyboard
    shortcut "Ctrl + O".

    {{< figure src="/images/3178532.png" height="450" >}}

5.  On the final screen, type `/work/<group name>/<username>` for Open
    directory. Use your HCC group name and username to replace
    `<group name>` and `<username>`. Then click on **OK**.  

    {{< figure src="/images/3178533.png" height="450" >}}

6.  Now you can drop and drag the files between your personal computer
    and the HCC supercomputers.   
    {{< figure src="/images/3178539.png" height="450" >}}

Tutorial Video
--------------

{{< youtube -Vh7SyC-3mA >}}


