+++
title = "BLAT"
description =  "How to run BLAT on HCC resources"
weight = "10"
+++


BLAT is a pairwise alignment tool similar to BLAST. It is more accurate and about 500 times faster than the existing tools for mRNA/DNA alignments and it is about 50 times faster with protein/protein alignments. BLAT accepts short and long query and database sequences as input files.


The basic usage of BLAT is:
{{< highlight bash >}}
$ blat database query output_alignment.txt [options]
{{< /highlight >}}
where **database** is the name of the database used for the alignment, **query** is the name of the input file of sequence data in `fasta/nib/2bit` format, and **output_alignment.txt** is the output alignment file.


Additional parameters for BLAT alignment can be found in the [manual] (http://genome.ucsc.edu/FAQ/FAQblat), or by using:
{{< highlight bash >}}
$ blat
{{< /highlight >}}


Running BLAT on Tusker with query file `input_reads.fasta` and database `db.fa` is shown below:
{{% panel header="`blat_alignment.submit`"%}}
{{< highlight bash >}}
#!/bin/sh
#SBATCH --job-name=Blat
#SBATCH --nodes=1
#SBATCH --ntasks-per-node=1
#SBATCH --time=168:00:00
#SBATCH --mem=50gb
#SBATCH --output=Blat.%J.out
#SBATCH --error=Blat.%J.err

module load blat/35x1

blat db.fa input_reads.fasta output_alignment.txt
{{< /highlight >}}
{{% /panel %}}

Although BLAT is a single threaded program (`#SBATCH --nodes=1`, `#SBATCH --ntasks-per-node=1`) it is still much faster than the other alignment tools.


### BLAT Output

BLAT output is a list containing the following information:

- the score of the alignment
- the region of query sequence that matches the database sequence
- the size of the query sequence
- the level of identity as a percentage of the alignment
- the chromosome and position that the query sequence maps to
