+++
title = "Trinity"
description = "How to use Trinity on HCC machines"
weight = "52"
+++


[Trinity] (https://github.com/trinityrnaseq/trinityrnaseq/wiki) is a method for efficient and robust de novo reconstruction of transcriptomes from RNA-Seq data. Trinity combines three independent software modules: `Inchworm`, `Chrysalis`, and `Butterfly`. All these modules can be applied sequentially to process large RNA-Seq datasets.


The basic usage of Trinity is:
{{< highlight bash >}}
$ Trinity --seqType [fa|fq] --JM <jellyfish_memory> --left input_reads_pair_1.[fa|fq] --right input_reads_pair_2.[fa|fq] [options]
{{< /highlight >}}
where **input_reads_pair_1.[fa|fq]** and **input_reads_pair_2.[fa|fq]** are the input paired-end files of sequence reads in fasta/fastq format, and **--seqType** is the type of these input reads. The option **--JM** defines the number of GB of system memory required for k-mer counting by jellyfish.

Additional Trinity **options** can be found in the Trinity website, or by typing:
{{< highlight bash >}}
$ Trinity
{{< /highlight >}}


Running the Trinity pipeline from beginning to end on large datasets may exceed the walltime limit for a single job. Therefore, Trinity provides a mechanism to run the workflow in four separate steps, where each step resumes from the previous one. The same Trinity command and options are run for each step, with an additional option that is included for the different steps. On the last step, the Trinity command is run as normal.

{{% panel theme="info" header="Step 1 Options" %}}
{{< highlight bash >}}
Trinity.pl [options] --no_run_chrysalis
{{< /highlight >}}
{{% /panel %}}

{{% panel theme="info" header="Step 2 Options" %}}
{{< highlight bash >}}
Trinity.pl [options] --no_run_quantifygraph
{{< /highlight >}}
{{% /panel %}}

{{% panel theme="info" header="Step 3 Options" %}}
{{< highlight bash >}}
Trinity.pl [options] --no_run_butterfly
{{< /highlight >}}
{{% /panel %}}

{{% panel theme="info" header="Step 4 Options" %}}
{{< highlight bash >}}
Trinity.pl [options]
{{< /highlight >}}
{{% /panel %}}

Each step may be run as its own job, providing a workaround for the single job walltime limit. To see how to run each step of Trinity as a single job under the SLURM scheduler on HCC, please check:
{{% children %}}


### Useful Information

In order to test the Trinity (trinity/r2014-04-13p1) performance on Tusker, we used three paired-end input fastq files, `small_1.fastq` and `small_2.fastq`, `medium_1.fastq` and `medium_2.fastq`, and `large_1.fastq` and `large_2.fastq`. Some statistics about the input files and the time and memory resources used by Trinity on Tusker are shown in the table below:
{{< readfile file="/static/html/trinity.html" >}}


{{% notice tip %}}
The Inchworm (step 1) and Chrysalis (step 2) steps can be memory intensive. A basic recommendation is to have **1GB of RAM per 1M ~76 base Illumina paired-end reads**.
{{% /notice %}}
