+++
title = "Scythe"
description =  "How to run Scythe on HCC resources"
weight = "10"
+++


[Scythe] (https://github.com/vsbuffalo/scythe) is a 3' end adapter trimmer that uses a Naive Bayesian approach to classify contaminant substrings in sequence reads. 3' ends often include poor quality bases which need to be removed prior the quality-based trimming, mapping, assemblies, and further analysis.


The basic usage of Scythe is:
{{< highlight bash >}}
$ scythe -a adapter_file.fasta input_reads.fastq -o output_reads.fastq
{{< /highlight >}}
where **adapter_file.fasta** is fasta input file of the adapter sequences that need to be removed from the 3' end of the sequence data, and **input_reads.fastq** is the input sequencing data in fastq format.

The file **output_reads.fastq** contains the sequencing reads with removed adapters. If the adapter sequences are unknown, Scythe by itself provides two adapter sequences that can be used with the **-a** option: **illumina_adapters.fa** and **truseq_adapters.fasta**.

More information about Scythe can found by typing:
{{< highlight bash >}}
$ scythe --help
{{< /highlight >}}


Simple Scythe script that uses the `illumina_adapters.fa` file and `input_reads.fastq` for Tusker is shown below:
{{% panel header="`scythe.submit`"%}}
{{< highlight bash >}}
#!/bin/sh
#SBATCH --job-name=Scythe
#SBATCH --nodes=1
#SBATCH --ntasks-per-node=1
#SBATCH --time=168:00:00
#SBATCH --mem=10gb
#SBATCH --output=Scythe.%J.out
#SBATCH --error=Scythe.%J.err

module load scythe/0.991

scythe -a ${SCYTHE_HOME}/illumina_adapters.fa input_reads.fastq -o output_reads.fastq
{{< /highlight >}}
{{% /panel %}}

Scythe is single threaded program, and therefore both `#SBATCH --nodes` and `#SBATCH --ntasks-per-node` are set to **1**. 

The two adapter sequences provided by Scythe are stored in **$SCYTHE_HOME**. Hence, to access the illumina adapter file use: `$SCYTHE_HOME/illumina_adapters.fa`, and to access the TruSeq file use: `$SCYTHE_HOME/truseq_adapters.fasta`.


### Scythe Output

Scythe returns fastq file of reads with removed adapter sequences.


### Useful Information

In order to test the Scythe (scythe/0.991) performance on Tusker, we used three paired-end input fastq files, `small_1.fastq` and `small_2.fastq`, `medium_1.fastq` and `medium_2.fastq`, and `large_1.fastq` and `large_2.fastq`. Some statistics about the input files and the time and memory resources used by Scythe on Tusker are shown in the table below:
{{< readfile file="/static/html/scythe.html" >}}
