+++
title = "QIIME"
description = "How to run QIIME jobs on HCC machines"
weight = "52"
+++


QIIME (Quantitative Insights Into Microbial Ecology) (http://qiime.org) is a bioinformatics software for conducting microbial community analysis. It is used to analyze raw DNA sequencing data generated from various sequencing technologies (Sanger, Roche/454, Illumina) from fungal, viral, bacterial and archaeal communities. As part of its analysis, QIIME produces lots of statistics, publication quality graphics and different options for viewing the outputs.


QIIME consists of a number of scripts that have different functionalities. Some of these include demultiplexing and quality filtering, OTU picking, phylogenetic reconstruction, taxonomic assignment and diversity analyses and visualizations.


Some common QIIME scripts are:

- validate_mapping_file.py
- split_libraries.py
- pick_de_novo_otus.py
- pick_closed_reference_otus.py
- pick_open_reference_otus.py
- pick_de_novo_otus.py
- summarize_taxa_through_plots.py
- multiple_rarefactions.py
- alpha_diversity.py
- collate_alpha.py
- make_rarefaction_plots.py
- jackknifed_beta_diversity.py
- otu_category_significance.py
- group_significance.py
- summarize_taxa.py
- group_significance.py


Sample QIIME submit script to run **pick_open_reference_otus.py** is:

{{% panel header="`qiime.submit`"%}}
{{< highlight bash >}}
#!/bin/sh
#SBATCH --job-name=QIIME
#SBATCH --nodes=1
#SBATCH --ntasks-per-node=8
#SBATCH --time=168:00:00
#SBATCH --mem=64gb
#SBATCH --output=qiime.%J.out
#SBATCH --error=qiime.%J.err

module load qiime/2.0

pick_open_reference_otus.py --parallel --jobs_to_start $SLURM_CPUS_ON_NODE -i /work/[groupname]/[username]/input.fasta -o /work/[groupname]/[username]/project/out_${SLURM_JOB_ID}

{{< /highlight >}}
{{% /panel %}}

To run QIIME with this script, update the input sequences option (**-i**) and the output directory path (**-o**).

In the example above, we use the variable **${SLURM_JOB_ID}** as part of the output directory. This ensures each QIIME run will have a unique output directory.
